Learn R Programming

promotionImpact (version 0.1.5)

detectOutliers: detect some outliers

Description

detectOutliers

Usage

detectOutliers(
  model,
  threshold = list(cooks.distance = 1, dfbetas = 1, dffits = 2),
  option = 2
)

Arguments

model

Execution result object : promotionImpact

threshold

List of threshold values to be determined as outliers if greater than the written values

option

The number of indicators that must be greater than the threshold values to be outliers.

Details

detectOutliers extracts outliers which affect the average effects of promotions.

Examples

Run this code
# NOT RUN {
pri1 <- promotionImpact(data=sim.data, promotion=sim.promotion, 
                       time.field = 'dt', target.field = 'simulated_sales', 
                       trend = FALSE, period = NULL, structural.change = FALSE,
                       logged = TRUE, differencing = TRUE, synergy.promotion = FALSE,
                       synergy.var = NULL, allow.missing = TRUE)
out <- detectOutliers(model = pri1, 
                      threshold = list(cooks.distance=1, dfbetas=1, dffits=2), option = 1)
# }

Run the code above in your browser using DataLab